PyQtGraph’s 3D Graphics System — pyqtgraph 0.11.0rc0 documentation

# PyQtGraph’s 3D Graphics System

The 3D graphics system in pyqtgraph is composed of a `view widget` and several graphics items (all subclasses of `GLGraphicsItem`) which can be added to a view widget.

Note 1: pyqtgraph.opengl is based on the deprecated OpenGL fixed-function pipeline. Although it is currently a functioning system, it is likely to be superceded in the future by VisPy.

Note 2: use of this system requires python-opengl bindings. Linux users should install the python-opengl packages from their distribution. Windows/OSX users can download from http://pyopengl.sourceforge.net.

Contents:

- GLViewWidget
- GLGridItem
- GLSurfacePlotItem
- GLVolumeItem
- GLImageItem
- GLMeshItem
- GLLinePlotItem
- GLAxisItem
- GLGraphicsItem
- GLScatterPlotItem
- MeshData